import math

def tension_menu():
    print("Tension Calculator")
    print("1: Static Tension (object hanging at rest: T = m * g)")
    print("2: Tension with Acceleration (T = m*(g + a) upward or T = m*(g - a) downward)")
    print("3: Tension in Atwood's Machine (T = (2*m1*m2*g)/(m1 + m2))")
    print("4: Tension in Circular Motion at the Bottom (T = m*g + m*v^2/r)")
    print("5: Tension in a Rope at an Angle (T = m*g / cos(θ))")
    print("6: Compound Atwood's Machine (three masses: m₁ vs. m₂ and m₃)")
    choice = input("Choose a method (1-6): ")
    return choice

def static_tension():
    m = float(input("Enter mass (m): "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s²]: "))
    T = m * g
    print("Tension (T) =", T)

def tension_with_acceleration():
    m = float(input("Enter mass (m): "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s²]: "))
    a = float(input("Enter acceleration (a): "))
    direction = input("Is the acceleration upward (u) or downward (d)? (u/d): ").lower()
    if direction == 'u':
        T = m * (g + a)
    elif direction == 'd':
        T = m * (g - a)
    else:
        print("Invalid direction input.")
        return
    print("Tension (T) =", T)

def atwood_machine_tension():
    m1 = float(input("Enter mass 1 (m₁): "))
    m2 = float(input("Enter mass 2 (m₂): "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s²]: "))
    T = (2 * m1 * m2 * g) / (m1 + m2)
    print("Tension (T) =", T)

def circular_motion_tension():
    m = float(input("Enter mass (m): "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s²]: "))
    v = float(input("Enter speed (v): "))
    r = float(input("Enter radius (r): "))
    T = m * g + m * (v**2) / r
    print("Tension (T) =", T)

def rope_angle_tension():
    m = float(input("Enter mass (m): "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s²]: "))
    theta_deg = float(input("Enter the angle (θ in degrees) from the vertical: "))
    theta_rad = math.radians(theta_deg)
    if math.cos(theta_rad) == 0:
        print("Invalid angle: cosine of the angle is zero.")
        return
    T = m * g / math.cos(theta_rad)
    print("Tension (T) =", T)

def compound_atwood_tension():
    print("Compound Atwood's Machine (m₁ on one side, m₂ and m₃ on the other)")
    m1 = float(input("Enter mass m₁: "))
    m2 = float(input("Enter mass m₂: "))
    m3 = float(input("Enter mass m₃: "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s²]: "))
    # Acceleration of the system:
    a = g * (m2 + m3 - m1) / (m1 + m2 + m3)
    # Tension in the main rope:
    T = (2 * m1 * (m2 + m3) * g) / (m1 + m2 + m3)
    print("Acceleration of the system (a) =", a)
    print("Tension in the main rope (T) =", T)

def main():
    choice = tension_menu()
    
    if choice == '1':
        static_tension()
    elif choice == '2':
        tension_with_acceleration()
    elif choice == '3':
        atwood_machine_tension()
    elif choice == '4':
        circular_motion_tension()
    elif choice == '5':
        rope_angle_tension()
    elif choice == '6':
        compound_atwood_tension()
    else:
        print("Invalid choice.")

# Automatically run the program
main()
